simplify definition of sqrthalf and capitalize it.
[paraslash.git] / stdin.h
diff --git a/stdin.h b/stdin.h
index 6931f330f440ca9005fadbbc93e11178bd9bee02..edb72cf894e6f2bf8e7d994f6dea0b45e83ebb5d 100644 (file)
--- a/stdin.h
+++ b/stdin.h
@@ -1,27 +1,25 @@
 /*
- * Copyright (C) 2006 Andre Noll <maan@systemlinux.org>
+ * Copyright (C) 2006-2009 Andre Noll <maan@systemlinux.org>
  *
  * Licensed under the GPL v2. For licencing details see COPYING.
  */
 
-/** \file stdin.h the stdin task structure and exported symbols from stdin.c */
+/** \file stdin.h The standard in task structure. */
 
-/**
- * the task structure used for reading from stdin
- */
+/** The task structure used for reading from stdin. */
 struct stdin_task {
-       /** input buffer */
+       /** Input buffer. */
        char *buf;
-       /** the size of \a buf */
+       /** The size of \a buf. */
        size_t bufsize;
-       /** number of bytes currently loaded in \a buf */
+       /** Number of bytes currently loaded in \a buf. */
        size_t loaded;
-       /** whether \p STDIN_FILENO was included in the read fd set */
+       /** Pointer to the error member of the consumer. */
+       int *output_error;
+       /** Whether \p STDIN_FILENO was included in the read fd set. */
        int check_fd;
-       /** the task structure */
+       /** The task structure. */
        struct task task;
-       /** non-zero on read error, or if a read from stdin returned zero */
-       int eof;
 };
 
 void stdin_set_defaults(struct stdin_task *sit);